@@ -5,6 +5,7 @@
 */
 
 #include "PrintManagerKded.h"
+#include "MarkerLevelChecker.h"
 #include "NewPrinterNotification.h"
 #include <KPluginFactory>
 
@@ -16,6 +17,7 @@ PrintManagerKded::PrintManagerKded(QObject *parent, const QVariantList &args)
     Q_UNUSED(args)
 
     new NewPrinterNotification(this);
+    new MarkerLevelChecker(this);
 }
 
 PrintManagerKded::~PrintManagerKded()
